import type Storage from '../storage.js';
import type Oas from 'oas';
export interface InstallerOptions {
    /**
     * Will initiate a dry run install process. Used for simulating installations within a unit test.
     */
    dryRun?: boolean;
    /**
     * Used for stubbing out the logger that we use within the installation process so it can be
     * easily introspected without having to mock out `console.*`.
     */
    logger?: (msg: string) => void;
}
export default abstract class CodeGenerator {
    spec: Oas;
    specPath: string;
    identifier: string;
    userAgent: string;
    requiredPackages: Record<string, {
        dependencyType: 'production' | 'development';
        reason: string;
        url?: string;
        version: string;
    }>;
    constructor(spec: Oas, specPath: string, identifier: string);
    abstract generate(): Promise<Record<string, string>>;
    abstract install(storage: Storage, opts?: InstallerOptions): Promise<void>;
    abstract compile(storage: Storage, opts?: InstallerOptions): Promise<void>;
    hasRequiredPackages(): boolean;
}
//# sourceMappingURL=codegenerator.d.ts.map